@@ -2,6 +2,7 @@
 #  define DATA_INCLUDED
 extern int scale;
 extern char version[8];
+extern int presult;
 extern PLAYING_MODE mode;
 extern int batch_mode;
 extern int swindle_mode;
@@ -142,7 +143,7 @@ extern int book_selection_width;
 extern int show_book;
 extern int learning;
 extern int learn_value;
-extern int time_abort;
+extern int abort_after_ply1;
 extern int abort_search;
 extern int iteration_depth;
 extern int root_alpha;
@@ -179,21 +180,20 @@ extern volatile int smp_idle;
 extern volatile int smp_threads;
 extern volatile int initialized_threads;
 extern int crafty_is_white;
-extern int nodes_between_time_checks;
-extern int nodes_per_second;
+extern unsigned int nodes_between_time_checks;
+extern unsigned int nodes_per_second;
 extern int next_time_check;
-extern int transposition_id;
+extern int transposition_age;
 extern int thinking;
 extern int pondering;
 extern int puzzling;
 extern int booking;
-extern int trojan_check;
 extern int computer_opponent;
 extern int display_options;
 extern int smp_max_threads;
 extern int smp_max_thread_group;
 extern int smp_split_at_root;
-extern int smp_split_nodes;
+extern unsigned int smp_split_nodes;
 extern unsigned int noise_level;
 extern int tc_moves;
 extern int tc_time;
@@ -229,10 +229,13 @@ extern int book_learn_nmoves;
 extern int book_learn_seekto;
 extern int usage_level;
 extern size_t hash_table_size;
+extern size_t hash_path_size;
+extern BITBOARD hash_path_mask;
 extern size_t pawn_hash_table_size;
 extern BITBOARD hash_mask;
 extern BITBOARD pawn_hash_mask;
 extern HASH_ENTRY *trans_ref;
+extern HPATH_ENTRY *hash_path;
 extern PAWN_HASH_ENTRY *pawn_hash_table;
 extern void *segments[MAX_BLOCKS + 32][2];
 extern int nsegments;
@@ -249,8 +252,6 @@ extern int knight_outpost[2][64];
 extern int bishop_outpost[2][64];
 extern int passed_pawn_value[2][2][8];
 extern int passed_pawn_candidate[2][2][8];
-extern int connected_passed_pawn_value[2];
-extern int blockading_passed_pawn_value[2][2][8];
 extern int passed_pawn_hidden[2];
 extern int doubled_pawn_value[2];
 extern int outside_passed[2];
@@ -258,7 +259,6 @@ extern int pawn_defects[2][8];
 extern int open_file[8];
 extern int half_open_file[8];
 extern int imbalance[9][9];
-extern int pp_rank_bonus[8];
 extern int pp_dist_bonus[8];
 extern int pp_bonus[8];
 extern int king_tropism_n[8];
@@ -342,9 +342,8 @@ extern unsigned char lsb[65536];
 extern unsigned char msb_8bit[256];
 extern unsigned char lsb_8bit[256];
 extern unsigned char pop_cnt_8bit[256];
-extern signed char is_outside[256][256];
+extern unsigned char is_outside[256][256];
 extern BITBOARD mask_pawn_connected[64];
-extern BITBOARD mask_pawn_duo[64];
 extern BITBOARD mask_pawn_isolated[64];
 extern BITBOARD mask_passed[2][64];
 extern BITBOARD mask_no_pattacks[2][64];
@@ -381,7 +380,6 @@ extern int cbEGTBCompBytes;
 #  endif
 extern int piece_values[7][2];
 extern int pawn_can_promote;
-extern int bad_trade;
 extern int wtm_bonus[2];
 extern int undeveloped_piece;
 extern int pawn_duo[2];
@@ -390,11 +388,9 @@ extern int pawn_weak[2];
 extern int lower_n;
 extern int mobility_score_n[4];
 extern int lower_b;
-extern int bishop_pair[2];
 extern int bishop_trapped;
 extern int bishop_with_wing_pawns[2];
 extern int mobility_score_b[4];
-extern int lower_r;
 extern int mobility_score_r[4];
 extern int rook_on_7th[2];
 extern int rook_open_file[2];
