@@ -1,6 +1,6 @@
 #include "chess.h"
 #include "data.h"
-/* last modified 06/05/98 */
+/* last modified 12/21/09 */
 /*
  *******************************************************************************
  *                                                                             *
@@ -11,6 +11,16 @@
  *   Otherwise, the superior side must have enough material to be able to force*
  *   a mate.                                                                   *
  *                                                                             *
+ *   Drawn() has 0 possible return values:                                     *
+ *                                                                             *
+ *   0:  Game is not a draw by rule or drawish in nature.                      *
+ *                                                                             *
+ *   1:  Game is a "technical draw" where material is even with no pawns and   *
+ *       the search is also returning draw scores as the best outcome.         *
+ *                                                                             *
+ *   2:  Game is an "actual draw" by FIDE rules, such as KB vs K, where mate   *
+ *       can't be forced, even with worst possible play by one side.           *
+ *                                                                             *
  *******************************************************************************
  */
 int Drawn(TREE * RESTRICT tree, int value) {
@@ -24,6 +34,16 @@ int Drawn(TREE * RESTRICT tree, int value) {
  */
   if (TotalPieces(white, pawn) || TotalPieces(black, pawn))
     return (0);
+/*
+ ************************************************************
+ *                                                          *
+ *   If the score suggests a mate has been found, this is   *
+ *   not a draw.                                            *
+ *                                                          *
+ ************************************************************
+ */
+  if (Abs(value) > MATE - 1024)
+    return (0);
 /*
  ************************************************************
  *                                                          *
@@ -33,8 +53,10 @@ int Drawn(TREE * RESTRICT tree, int value) {
  *                                                          *
  ************************************************************
  */
-  if (TotalPieces(white, occupied) < 5 && TotalPieces(black, occupied) < 5)
+  if (TotalPieces(white, occupied) + TotalPieces(black, occupied) < 4)
     return (2);
+  if (TotalPieces(white, occupied) < 5 && TotalPieces(black, occupied) < 5)
+    return (1);
   if (TotalPieces(white, occupied) == 5 || TotalPieces(white, occupied) > 6)
     return (0);
   if (TotalPieces(black, occupied) == 5 || TotalPieces(black, occupied) > 6)
@@ -42,7 +64,7 @@ int Drawn(TREE * RESTRICT tree, int value) {
   if ((TotalPieces(white, occupied) == 6 && !Bishops(white) && Material > 0)
       || (TotalPieces(black, occupied) == 6 && !Bishops(black) &&
           Material < 0))
-    return (2);
+    return (1);
 /*
  ************************************************************
  *                                                          *
