@@ -1,8 +1,5 @@
-#if defined(SMP)
-
-#  undef Pause
-#  define Pause()
-
+/* *INDENT-OFF* */
+#if (CPUS > 1)
 /*
  *******************************************************************************
  *                                                                             *
@@ -11,27 +8,20 @@
  *******************************************************************************
  */
 #  if defined(_WIN32) || defined(_WIN64)
-
 #    define pthread_attr_t  HANDLE
 #    define pthread_t       HANDLE
 #    define thread_t        HANDLE
-
 extern pthread_t NumaStartThread(void *func, void *args);
 
 #    if ((defined (_M_IA64) || defined (_M_AMD64)) && !defined(NT_INTEREX))
-
 #      include <windows.h>
-
 #      pragma intrinsic (_InterlockedExchange)
-
 typedef volatile LONG lock_t[1];
 
 #      define LockInit(v)      ((v)[0] = 0)
 #      define LockFree(v)      ((v)[0] = 0)
 #      define Unlock(v)        ((v)[0] = 0)
-
-__forceinline void Lock(volatile LONG * hPtr)
-{
+__forceinline void Lock(volatile LONG * hPtr) {
   int iValue;
 
   for (;;) {
@@ -41,19 +31,15 @@ __forceinline void Lock(volatile LONG * hPtr)
     while (*hPtr);
   }
 }
-
 #    else                       /* NT non-Alpha/Intel, without assembler Lock() */
-
 #      define lock_t           volatile int
 #      define LockInit(v)      ((v) = 0)
 #      define LockFree(v)      ((v) = 0)
-#      define Lock(v)          do {                                         \
-                             while(InterlockedExchange((LPLONG)&(v),1) != 0);  \
-                           } while (0)
+#      define Lock(v)  do {                                                   \
+                         while(InterlockedExchange((LPLONG)&(v),1) != 0);     \
+                       } while (0)
 #      define Unlock(v)        ((v) = 0)
-
 #    endif                      /* architecture check */
-
 #  else
 /*
  *******************************************************************************
@@ -63,50 +49,37 @@ __forceinline void Lock(volatile LONG * hPtr)
  *                                                                             *
  *******************************************************************************
  */
-
-#    if defined(ALPHA)
-
-#      include <machine/builtins.h>
-
-#      define lock_t           volatile long
-#      define LockInit(v)      ((v) = 0)
-#      define LockFree(v)      ((v) = 0)
-#      define Lock(v)          __LOCK_LONG(&(v))
-#      define Unlock(v)        __UNLOCK_LONG(&(v))
-
-#    elif defined(POWERPC)
+#    if defined(POWERPC)
                         /* OS X */
-
 #      include <libkern/OSAtomic.h>
-
 #      define lock_t				OSSpinLock
 #      define LockInit(v)		((v) = 0)
 #      define LockFree(v)		((v) = 0)
 #      define Lock(v)			OSSpinLockLock(&(v))
 #      define Unlock(v)			OSSpinLockUnlock(&(v))
-
 #    else                       /* X86 */
-
-#      undef Pause
-#      define Pause() ({asm volatile ("pause");})
-
-static void __inline__ LockX86(volatile int *lock)
-{
+static void __inline__ LockX86(volatile int *lock) {
   int dummy;
-  asm __volatile__("1:          movl    $1, %0" "\n\t"
-      "            xchgl   (%1), %0" "\n\t" "            testl   %0, %0" "\n\t"
-      "            jz      3f" "\n\t" "2:          pause" "\n\t"
-      "            movl    (%1), %0" "\n\t" "            testl   %0, %0" "\n\t"
-      "            jnz     2b" "\n\t" "            jmp     1b" "\n\t" "3:"
-      "\n\t":"=&q"(dummy)
+  asm __volatile__(
+      "1:          movl    $1, %0"   "\n\t"
+      "            xchgl   (%1), %0" "\n\t"
+      "            testl   %0, %0"   "\n\t"
+      "            jz      3f"       "\n\t"
+      "2:          pause"            "\n\t"
+      "            movl    (%1), %0" "\n\t"
+      "            testl   %0, %0"   "\n\t"
+      "            jnz     2b"       "\n\t"
+      "            jmp     1b"       "\n\t"
+      "3:"                           "\n\t"
+      :"=&q"(dummy)
       :"q"(lock)
-      :"cc");
+      :"cc", "memory");
 }
-
-static void __inline__ UnlockX86(volatile int *lock)
-{
+static void __inline__ UnlockX86(volatile int *lock) {
   int dummy;
-  asm __volatile__("movl    $0, (%1)":"=&q"(dummy)
+  asm __volatile__(
+      "movl    $0, (%1)"
+      :"=&q"(dummy)
       :"q"(lock));
 }
 
@@ -115,14 +88,13 @@ static void __inline__ UnlockX86(volatile int *lock)
 #      define Unlock(p)             (UnlockX86(&p))
 #      define Lock(p)               (LockX86(&p))
 #      define lock_t                volatile int
-
 #    endif
-
 #  endif                        /* windows or unix */
-
 #else
 #  define LockInit(p)
 #  define LockFree(p)
 #  define Lock(p)
 #  define Unlock(p)
+#  define lock_t volatile int
 #endif                          /*  SMP code */
+/* *INDENT-ON* */
