@@ -17,8 +17,7 @@
  *                                                                             *
  *******************************************************************************
  */
-void ResignOrDraw(TREE * RESTRICT tree, int value)
-{
+void ResignOrDraw(TREE * RESTRICT tree, int value) {
   int result = 0;
 
 /*
@@ -42,13 +41,13 @@ void ResignOrDraw(TREE * RESTRICT tree, int value)
  *   or win out.                                            *
  *                                                          *
  *   If the value is below the resignation threshold, then  *
- *   crafty should resign and get on to the next game. Note *
+ *   Crafty should resign and get on to the next game. Note *
  *   that it is necessary to have a bad score for           *
  *   <resign_count> moves in a row before resigning.        *
  *                                                          *
  ************************************************************
  */
-  if ((tc_increment > 200) || (tc_time_remaining_opponent >= 3000)) {
+  if ((tc_increment > 200) || (tc_time_remaining[Flip(root_wtm)] >= 3000)) {
     if (resign) {
       if (value < -(MATE - 15)) {
         if (++resign_counter >= resign_count)
@@ -64,7 +63,7 @@ void ResignOrDraw(TREE * RESTRICT tree, int value)
  ************************************************************
  *                                                          *
  *   If the value is almost equal to the draw score, then   *
- *   crafty should offer the opponent a draw.  Note that  . *
+ *   Crafty should offer the opponent a draw.  Note that  . *
  *   it is necessary that the draw score occur on exactly   *
  *   <draw_count> moves in a row before making the offer.   *
  *   Note also that the draw offer will be repeated every   *
@@ -73,8 +72,8 @@ void ResignOrDraw(TREE * RESTRICT tree, int value)
  *                                                          *
  ************************************************************
  */
-  if ((tc_increment > 200) || (tc_time_remaining_opponent >= 3000)) {
-    if (abs(abs(value) - abs(DrawScore(wtm))) < 2 && moves_out_of_book > 3) {
+  if ((tc_increment > 200) || (tc_time_remaining[Flip(root_wtm)] >= 3000)) {
+    if (Abs(Abs(value) - Abs(DrawScore(wtm))) < 2 && moves_out_of_book > 3) {
       if (++draw_counter >= draw_count) {
         draw_counter = 0;
         result = 2;
@@ -87,7 +86,7 @@ void ResignOrDraw(TREE * RESTRICT tree, int value)
  *                                                          *
  *   Now print the draw offer or resignation if appropriate *
  *   but be sure and do it in a form that ICC/FICS will     *
- *   understand if the "ics" or "xboard" flag is set.       *
+ *   understand if the "xboard" flag is set.                *
  *                                                          *
  *   Note that we also use the "speak" facility to verbally *
  *   offer draws or resign if the "speech" variable has     *
@@ -96,9 +95,8 @@ void ResignOrDraw(TREE * RESTRICT tree, int value)
  ************************************************************
  */
   if (result == 1) {
-    int val = (crafty_is_white) ? -300 : 300;
-
-    LearnBook(val, 0, 1, 2);
+    learn_value = (crafty_is_white) ? -300 : 300;
+    LearnBook();
     if (xboard)
       Print(4095, "resign\n");
     if (audible_alarm)
@@ -120,7 +118,7 @@ void ResignOrDraw(TREE * RESTRICT tree, int value)
   }
   if (offer_draws && result == 2) {
     draw_offered = 1;
-    if (!ics && !xboard) {
+    if (!xboard) {
       Print(128, "\nI offer a draw.\n\n");
       if (audible_alarm)
         printf("%c", audible_alarm);
