@@ -1,10 +1,6 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "chess.h"
 #include "data.h"
-
-/* last modified 08/07/05 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
@@ -12,40 +8,39 @@
  *   measure its performance on a particular machine, or to evaluate its skill *
  *   after modifying it in some way.                                           *
  *                                                                             *
- *   the test is initiated by using the "test <filename>" command to read in   *
- *   the suite of problems from file <filename>.  the format of this file is   *
+ *   The test is initiated by using the "test <filename>" command to read in   *
+ *   the suite of problems from file <filename>.  The format of this file is   *
  *   as follows:                                                               *
  *                                                                             *
- *   setboard <forsythe-string>:  this sets the board position using the usual *
+ *   Setboard <forsythe-string>:  This sets the board position using the usual *
  *   forsythe notation (see module SetBoard() in setc for a full ex-           *
  *   planation of the syntax).                                                 *
  *                                                                             *
- *   solution <move1> <move2> ... <moven>:  this provides a solution move (or  *
- *   set of solution moves if more than one is correct).  if the search finds  *
+ *   Solution <move1> <move2> ... <moven>:  this provides a solution move (or  *
+ *   set of solution moves if more than one is correct).  If the search finds  *
  *   one of these moves, then the prblem is counted as correct, otherwise it   *
  *   is counted wrong.                                                         *
  *                                                                             *
- *   after reading these two lines, the program then searches to whatever time *
+ *   After reading these two lines, the program then searches to whatever time *
  *   or depth limit has been set, when it reaches the end-of-file condition or *
  *   when it reads a record containing the string "end" it then displays the   *
  *   number correct and the number missed.                                     *
  *                                                                             *
  *******************************************************************************
  */
-void Test(char *filename)
-{
+void Test(char *filename) {
   FILE *test_input;
   int i, move, right = 0, wrong = 0, correct;
   int time = 0, len;
   BITBOARD nodes = 0;
-  char *eof;
+  char *eof, *delim;
   float avg_depth = 0.0;
-  TREE *const tree = shared->local[0];
+  TREE *const tree = block[0];
 
 /*
  ************************************************************
  *                                                          *
- *   read in the position and then the solutions.  after    *
+ *   Read in the position and then the solutions.  After    *
  *   executing a search to find the best move (according    *
  *   to the program, anyway) compare it against the list    *
  *   of solutions and count it right or wrong.              *
@@ -57,25 +52,23 @@ void Test(char *filename)
     return;
   }
   Print(4095, "\n");
-  eof = fgets(buffer, 512, test_input);
+  eof = fgets(buffer, 4096, test_input);
   if (strstr(buffer, "title"));
   else {
     fclose(test_input);
     TestEPD(filename);
     return;
   }
-
   if (book_file) {
     fclose(book_file);
-    fclose(books_file);
     book_file = 0;
+  }
+  if (books_file) {
+    fclose(books_file);
     books_file = 0;
   }
   while (1) {
-    eof = fgets(buffer, 512, test_input);
     if (eof) {
-      char *delim;
-
       delim = strchr(buffer, '\n');
       if (delim)
         *delim = 0;
@@ -134,13 +127,13 @@ void Test(char *filename)
       Print(4095, "\n");
       InitializeHashTables();
       last_pv.pathd = 0;
-      shared->thinking = 1;
+      thinking = 1;
       tree->position[1] = tree->position[0];
       (void) Iterate(wtm, think, 0);
-      shared->thinking = 0;
+      thinking = 0;
       nodes += tree->nodes_searched;
-      avg_depth += (float) shared->iteration_depth;
-      time += (shared->end_time - shared->start_time);
+      avg_depth += (float) iteration_depth;
+      time += (end_time - start_time);
       correct = solution_type;
       for (i = 0; i < number_of_solutions; i++) {
         if (!solution_type) {
@@ -159,11 +152,12 @@ void Test(char *filename)
             right, right + wrong);
       }
     }
+    eof = fgets(buffer, 4096, test_input);
   }
 /*
  ************************************************************
  *                                                          *
- *   now print the results.                                 *
+ *   Now print the results.                                 *
  *                                                          *
  ************************************************************
  */
@@ -180,14 +174,16 @@ void Test(char *filename)
     Print(4095, "total nodes searched..............%12llu\n", nodes);
     Print(4095, "average search depth..............%12.1f\n",
         avg_depth / (right + wrong));
-    Print(4095, "nodes per second..................%12d\n", nodes * 100 / time);
-    Print(4095, "total time........................%12s\n", DisplayTime(time));
+    Print(4095, "nodes per second..................%12d\n",
+        nodes * 100 / Max(time, 1));
+    Print(4095, "total time........................%12s\n",
+        DisplayTime(time));
   }
   input_stream = stdin;
   early_exit = 99;
 }
 
-/* last modified 08/07/05 */
+/* last modified 01/17/09 */
 /*
  *******************************************************************************
  *                                                                             *
@@ -195,35 +191,34 @@ void Test(char *filename)
  *   measure its performance on a particular machine, or to evaluate its skill *
  *   after modifying it in some way.                                           *
  *                                                                             *
- *   the test is initiated by using the "test <filename>" command to read in   *
- *   the suite of problems from file <filename>.  the format of this file is   *
+ *   The test is initiated by using the "test <filename>" command to read in   *
+ *   the suite of problems from file <filename>.  The format of this file is   *
  *   as follows:                                                               *
  *                                                                             *
  *   <forsythe-string>  am/bm move1 move2 etc; title "xxx"                     *
  *                                                                             *
- *   am means "avoid move" and bm means "best move".  each test position may   *
+ *   Am means "avoid move" and bm means "best move".  Each test position may   *
  *   have multiple moves to avoid or that are best, but both am and bm may not *
  *   appear on one position.                                                   *
  *                                                                             *
- *   the title is just a comment that is given in the program output to make it*
+ *   The title is just a comment that is given in the program output to make it*
  *   easier to match output to specific positions.                             *
  *                                                                             *
  *******************************************************************************
  */
-void TestEPD(char *filename)
-{
+void TestEPD(char *filename) {
   FILE *test_input;
   int i, move, right = 0, wrong = 0, correct;
   int time = 0, len;
   BITBOARD nodes = 0;
   char *eof, *mvs, *title;
   float avg_depth = 0.0;
-  TREE *const tree = shared->local[0];
+  TREE *const tree = block[0];
 
 /*
  ************************************************************
  *                                                          *
- *   read in the position and then the solutions.  after    *
+ *   Read in the position and then the solutions.  After    *
  *   executing a search to find the best move (according    *
  *   to the program, anyway) compare it against the list    *
  *   of solutions and count it right or wrong.              *
@@ -236,12 +231,14 @@ void TestEPD(char *filename)
   }
   if (book_file) {
     fclose(book_file);
-    fclose(books_file);
     book_file = 0;
+  }
+  if (books_file) {
+    fclose(books_file);
     books_file = 0;
   }
   while (1) {
-    eof = fgets(buffer, 512, test_input);
+    eof = fgets(buffer, 4096, test_input);
     if (eof) {
       char *delim;
 
@@ -294,6 +291,8 @@ void TestEPD(char *filename)
       solution_type = 1;
     Print(4095, "solution ");
     for (i = 1; i < nargs; i++) {
+      if (!strcmp(args[i], "c0"))
+        break;
       move = InputMove(tree, args[i], 0, wtm, 0, 0);
       if (move) {
         solutions[number_of_solutions] = move;
@@ -309,13 +308,13 @@ void TestEPD(char *filename)
     Print(4095, "\n");
     InitializeHashTables();
     last_pv.pathd = 0;
-    shared->thinking = 1;
+    thinking = 1;
     tree->position[1] = tree->position[0];
     (void) Iterate(wtm, think, 0);
-    shared->thinking = 0;
+    thinking = 0;
     nodes += tree->nodes_searched;
-    avg_depth += (float) shared->iteration_depth;
-    time += (shared->end_time - shared->start_time);
+    avg_depth += (float) iteration_depth;
+    time += (end_time - start_time);
     correct = solution_type;
     for (i = 0; i < number_of_solutions; i++) {
       if (!solution_type) {
@@ -326,8 +325,8 @@ void TestEPD(char *filename)
     }
     if (correct) {
       right++;
-      Print(4095, "----------------------> solution correct (%d/%d).\n", right,
-          right + wrong);
+      Print(4095, "----------------------> solution correct (%d/%d).\n",
+          right, right + wrong);
     } else {
       wrong++;
       Print(4095, "----------------------> solution incorrect (%d/%d).\n",
@@ -337,7 +336,7 @@ void TestEPD(char *filename)
 /*
  ************************************************************
  *                                                          *
- *   now print the results.                                 *
+ *   Now print the results.                                 *
  *                                                          *
  ************************************************************
  */
@@ -354,8 +353,10 @@ void TestEPD(char *filename)
     Print(4095, "total nodes searched..............%12llu\n", nodes);
     Print(4095, "average search depth..............%12.1f\n",
         avg_depth / (right + wrong));
-    Print(4095, "nodes per second..................%12d\n", nodes * 100 / time);
-    Print(4095, "total time........................%12s\n", DisplayTime(time));
+    Print(4095, "nodes per second..................%12d\n",
+        nodes * 100 / Max(1, time));
+    Print(4095, "total time........................%12s\n",
+        DisplayTime(time));
   }
   input_stream = stdin;
   early_exit = 99;
